#ifndef GEBEMONITOR_H_
#define GEBEMONITOR_H_

// ---------------------------------------------------------------
// Driverversion 2.0.0.35 Beta
// ---------------------------------------------------------------

// The following ifdef block is the standard way of creating macros which make exporting
// from a DLL simpler. All files within this DLL are compiled with the GEBE_EXPORTS
// symbol defined on the command line. This symbol should not be defined on any project
// that uses this DLL. This way any other project whose source files include this file see
// GEBE_API functions as being imported from a DLL, wheras this DLL sees symbols
// defined with this macro as being exported.



#ifdef GEBE_EXPORTS
#define GEBE_API __declspec(dllexport)
#else
#define GEBE_API __declspec(dllimport)
#endif

#ifdef __cplusplus
extern "C" {
#endif

enum PrinterParameter{PrinterOnline=1,BufferFull,HeadOpen,PaperEnd,PaperRest,Aux,Cutter,TempHigh,TempLow,LowVoltage,HighVoltage,Charge,TrickleCharge};

//----------------------------------------------------------------
// Name:    GEBE_Request
//
// IN:      gebeport:   Nullterminated portname (e.g. "GEBE0:\0")
//
// OUT:     Status
//----------------------------------------------------------------
GEBE_API BOOL WINAPI GEBE_Request(WCHAR *gebeport);


//----------------------------------------------------------------
// Name:    GEBE_Status
//
// IN:      gebeport:   Nullterminated portname (e.g. "GEBE0:\0")
//          p:          Type of feature (for options please look at the "enum PrinterParameter")
//
// OUT:     Status
// 
// Start a GEBE_Request before. Otherwise you get wrong results.
//----------------------------------------------------------------
GEBE_API BOOL WINAPI GEBE_Status(WCHAR *gebeport, enum PrinterParameter p);


//----------------------------------------------------------------
// Name:    GEBE_LastStatus
//
// IN:      Nullterminated portname (e.g. "GEBE0:\0")
//
// OUT:     Last received statuschar
//
// Get the last char which was sent by printer after
// the last GetPrinterStatus() command
//----------------------------------------------------------------
GEBE_API char WINAPI GEBE_LastStatus(WCHAR *gebeport);


//----------------------------------------------------------------
// Name:    GEBE_Card (not implemented yet!)
//
// IN:      gebeport:   Nullterminated portname (e.g. "GEBE0:\0")
//          buffer:     Pointer to a char-array (T1>=79, T2>=40, T3>=107)
//          stream:     Number of datastream (0=T1, 1=T2, 2=T3)
//
// OUT:     Number of received databytes
//
// Get data from a optional cardreader (need GetPrinterStatus).
//----------------------------------------------------------------
GEBE_API int WINAPI GEBE_Card(WCHAR *gebeport, char *buffer, int stream);


//----------------------------------------------------------------
// Name:    GEBE_GetPort
//
// IN:      gebeport:   Nullterminated GeBE Port name (e.g. "GEBE0:\0")
//          outport:    Pointer to WCHAR Array where will stored the returned portname
//
// OUT:     Status
//----------------------------------------------------------------
GEBE_API BOOL WINAPI GEBE_GetPort(WCHAR *gebeport, WCHAR *outport);


//----------------------------------------------------------------
// Name:    GEBE_SetPort
//
// IN:      gebeport:   Nullterminated GeBE Port name (e.g. "GEBE0:\0")
//          outport:    Nullterminated portname of the printer (e.g. "COM1:\0")
//
// OUT:     Status
//----------------------------------------------------------------
GEBE_API BOOL WINAPI GEBE_SetPort(WCHAR *gebeport, WCHAR *outport);

//----------------------------------------------------------------
// Name:    GEBE_SendData
//
// IN:      gebeport:       Nullterminated GeBE Port name (e.g. "GEBE0:\0")
//          buffer:         Pointer to databuffer
//          numberOfBytes:  Number of bytes to send
//
// OUT:     Status
//----------------------------------------------------------------
GEBE_API BOOL WINAPI GEBE_SendData(WCHAR *gebeport, char *buffer, DWORD numberOfBytes);

#ifdef __cplusplus
}
#endif


#endif /*GEBEMONITOR_H_*/
